@@ -1,3 +1,5 @@
+from typing import Optional
+
 import click
 
 
@@ -18,7 +20,7 @@ def wallet_cmd() -> None:
 @click.option("-i", "--id", help="Id of the wallet to use", type=int, default=1, show_default=True, required=True)
 @click.option("-tx", "--tx_id", help="transaction id to search for", type=str, required=True)
 @click.option("--verbose", "-v", count=True, type=int)
-def get_transaction_cmd(wallet_rpc_port: int, fingerprint: int, id: int, tx_id: str, verbose: int) -> None:
+def get_transaction_cmd(wallet_rpc_port: Optional[int], fingerprint: int, id: int, tx_id: str, verbose: int) -> None:
     extra_params = {"id": id, "tx_id": tx_id, "verbose": verbose}
     import asyncio
     from .wallet_funcs import execute_with_wallet, get_transaction
@@ -46,7 +48,7 @@ def get_transaction_cmd(wallet_rpc_port: int, fingerprint: int, id: int, tx_id:
     required=True,
 )
 @click.option("--verbose", "-v", count=True, type=int)
-def get_transactions_cmd(wallet_rpc_port: int, fingerprint: int, id: int, offset: int, verbose: bool) -> None:
+def get_transactions_cmd(wallet_rpc_port: Optional[int], fingerprint: int, id: int, offset: int, verbose: bool) -> None:
     extra_params = {"id": id, "verbose": verbose, "offset": offset}
     import asyncio
     from .wallet_funcs import execute_with_wallet, get_transactions
@@ -79,7 +81,7 @@ def get_transactions_cmd(wallet_rpc_port: int, fingerprint: int, id: int, offset
     "-o", "--override", help="Submits transaction without checking for unusual values", is_flag=True, default=False
 )
 def send_cmd(
-    wallet_rpc_port: int, fingerprint: int, id: int, amount: str, fee: str, address: str, override: bool
+    wallet_rpc_port: Optional[int], fingerprint: int, id: int, amount: str, fee: str, address: str, override: bool
 ) -> None:
     extra_params = {"id": id, "amount": amount, "fee": fee, "address": address, "override": override}
     import asyncio
@@ -97,7 +99,7 @@ def send_cmd(
     default=None,
 )
 @click.option("-f", "--fingerprint", help="Set the fingerprint to specify which wallet to use", type=int)
-def show_cmd(wallet_rpc_port: int, fingerprint: int) -> None:
+def show_cmd(wallet_rpc_port: Optional[int], fingerprint: int) -> None:
     import asyncio
     from .wallet_funcs import execute_with_wallet, print_balances
 
@@ -114,7 +116,7 @@ def show_cmd(wallet_rpc_port: int, fingerprint: int) -> None:
 )
 @click.option("-i", "--id", help="Id of the wallet to use", type=int, default=1, show_default=True, required=True)
 @click.option("-f", "--fingerprint", help="Set the fingerprint to specify which wallet to use", type=int)
-def get_address_cmd(wallet_rpc_port: int, id, fingerprint: int) -> None:
+def get_address_cmd(wallet_rpc_port: Optional[int], id, fingerprint: int) -> None:
     extra_params = {"id": id}
     import asyncio
     from .wallet_funcs import execute_with_wallet, get_address
@@ -134,7 +136,7 @@ def get_address_cmd(wallet_rpc_port: int, id, fingerprint: int) -> None:
 )
 @click.option("-i", "--id", help="Id of the wallet to use", type=int, default=1, show_default=True, required=True)
 @click.option("-f", "--fingerprint", help="Set the fingerprint to specify which wallet to use", type=int)
-def delete_unconfirmed_transactions_cmd(wallet_rpc_port: int, id, fingerprint: int) -> None:
+def delete_unconfirmed_transactions_cmd(wallet_rpc_port: Optional[int], id, fingerprint: int) -> None:
     extra_params = {"id": id}
     import asyncio
     from .wallet_funcs import execute_with_wallet, delete_unconfirmed_transactions
