@@ -99,6 +99,8 @@ def generate_replacements(defaults, conf, dir, test_files):
     replacements["TEST_NAME"] = test_name(str(dir))
     if "test_name" in conf:
         replacements["TEST_NAME"] = conf["test_name"]
+    for var in conf["custom_vars"]:
+        replacements[var] = conf[var] if var in conf else ""
     return replacements
 
 
