@@ -9,7 +9,7 @@ from chia.full_node.signage_point import SignagePoint
 from chia.protocols import full_node_protocol
 from chia.rpc.full_node_rpc_api import FullNodeRpcApi
 from chia.rpc.full_node_rpc_client import FullNodeRpcClient
-from chia.rpc.rpc_server import start_rpc_server
+from chia.rpc.rpc_server import NodeType, start_rpc_server
 from chia.simulator.simulator_protocol import FarmNewBlockProtocol
 from chia.types.spend_bundle import SpendBundle
 from chia.types.unfinished_block import UnfinishedBlock
@@ -113,6 +113,12 @@ class TestRpc:
             print(coins)
             assert len(coins) >= 1
 
+            pid = list(blocks[-1].get_included_reward_coins())[0].parent_coin_info
+            pid_2 = list(blocks[-1].get_included_reward_coins())[1].parent_coin_info
+            coins = await client.get_coin_records_by_parent_ids([pid, pid_2])
+            print(coins)
+            assert len(coins) == 2
+
             additions, removals = await client.get_additions_and_removals(blocks[-1].header_hash)
             assert len(additions) >= 2 and len(removals) == 0
 
@@ -186,7 +192,9 @@ class TestRpc:
 
             await time_out_assert(10, num_connections, 1)
             connections = await client.get_connections()
-
+            assert NodeType(connections[0]["type"]) == NodeType.FULL_NODE.value
+            assert len(await client.get_connections(NodeType.FULL_NODE)) == 1
+            assert len(await client.get_connections(NodeType.FARMER)) == 0
             await client.close_connection(connections[0]["node_id"])
             await time_out_assert(10, num_connections, 0)
         finally:
