@@ -1,5 +1,3 @@
-from unittest import TestCase
-
 from clvm_tools import binutils
 from clvm_tools.clvmc import compile_clvm_text
 
@@ -84,7 +82,7 @@ EXPECTED_OUTPUT = (
 )
 
 
-class TestROM(TestCase):
+class TestROM:
     def test_rom_inputs(self):
         # this test checks that the generator just works
         # It's useful for debugging the generator prior to having the ROM invoke it.
@@ -126,7 +124,7 @@ class TestROM(TestCase):
         coin_spends = r.first()
         for coin_spend in coin_spends.as_iter():
             extra_data = coin_spend.rest().rest().rest().rest()
-            self.assertEqual(extra_data.as_atom_list(), b"extra data for coin".split())
+            assert extra_data.as_atom_list() == b"extra data for coin".split()
 
     def test_block_extras(self):
         # the ROM supports extra data after the coin spend list. This test checks that it actually gets passed through
@@ -134,4 +132,4 @@ class TestROM(TestCase):
         gen = block_generator()
         cost, r = run_generator(gen, max_cost=MAX_COST)
         extra_block_data = r.rest()
-        self.assertEqual(extra_block_data.as_atom_list(), b"extra data for block".split())
+        assert extra_block_data.as_atom_list() == b"extra data for block".split()
