@@ -9,7 +9,7 @@ from chia.util.generator_tools import additions_for_npc
 
 
 def run_and_get_removals_and_additions(
-    block: FullBlock, max_cost: int, safe_mode=False
+    block: FullBlock, max_cost: int, cost_per_byte: int, safe_mode=False
 ) -> Tuple[List[bytes32], List[Coin]]:
     removals: List[bytes32] = []
     additions: List[Coin] = []
@@ -19,7 +19,9 @@ def run_and_get_removals_and_additions(
         return [], []
 
     if block.transactions_generator is not None:
-        npc_result = get_name_puzzle_conditions(BlockGenerator(block.transactions_generator, []), max_cost, safe_mode)
+        npc_result = get_name_puzzle_conditions(
+            BlockGenerator(block.transactions_generator, []), max_cost, cost_per_byte=cost_per_byte, safe_mode=safe_mode
+        )
         # build removals list
         for npc in npc_result.npc_list:
             removals.append(npc.coin_name)
